/*
Copyright 2006 Frank van der Loo

This file is part of Paratim.

Paratim is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Paratim is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Paratim; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "bomb.h"

// Returns the absolute value of a double
double dabs(double value)
{
	if (value < 0.0)
		return value * -1.0;
	else
		return value;
}

// Bomb constructor, sets some default values
bomb::bomb() : sprite(DATADIR, "/bomb.bmp")
{
	#ifdef DEBUG
	  std::cout << "In bomb constructor\n";
	#endif
	dst.x = -20;
	dst.y = -20;
	dst.w = image->w;
	dst.h = image->h;
	black.w = image->w + 3;
	black.h = image->h + 3;
	black.x = dst.x - 3;
	black.y = dst.y - 3;	
	points = 30;
	end = false;
	#ifdef DEBUG
	  std::cout << "Einde bomb constructor\n";
	#endif
}

// Initializes the bomb: sets the begin position and calculates to where it should drop
void bomb::init_bomb(int x, int y)
{
	dst.x = x;
	dst.y = y;
	ddstx = dst.x;
	ddsty = dst.y;
	double dx = GUN_X - dst.x;
	double dy = GUN_Y - dst.y;
	if (dabs(dx) > dabs(dy))
	{
		y_direction = dy/dx;
		x_direction = 1.0;
	}
	else
	{
		x_direction = dx/dy;
		y_direction = 1.0;
	}
	#ifdef DEBUG
	  std::cout << "dx: " << dx << ", dy: " << dy << std::endl;
	  std::cout << "x_direction[" << x_direction << "], y_direction[" << y_direction << "]\n";
	  std::cout << "x: " << dst.x << " y: " << dst.y << std::endl;
	#endif
}

// Moves the bomb the amount of pixels for one frame
void bomb::move()
{
	#ifdef DEBUG
	  std::cout << "x_direction[" << x_direction << "], y_direction[" << y_direction << "]\n";
	  std::cout << "x: " << dst.x << " y: " << dst.y << std::endl;
	  std::cout << "dx: " << ddstx << " dy: " << ddsty << std::endl;
	#endif
	if (dst.x > 0 && dst.x < WIDTH && dst.y > 0 && dst.y < HEIGHT)	//CHANGE!!!!!!!!!!!!!!!!
	{
		ddstx += (x_direction*4);
		ddsty += (y_direction*4);
		
		dst.y = (int) (ddsty+0.5);
		dst.x = (int) (ddstx+0.5);

		black.x = dst.x - 3;
		black.y = dst.y - 3;
	}
	else
	{
		end = true;
	}
}

// Checks if the bomb hits the gun
bool bomb::hitsGun()
{
	if ((dst.x > GUN_X-5 && dst.x < GUN_X+5) && (dst.y > GUN_Y-5 && dst.y < GUN_Y+5))
	{
		std::cout << "\nHit by bomb!\n";
		return true;
	}
	return false;
}

// If the bomb is still there, move it
bool move_bomb(SDL_Surface *screen, bomb *plane_bomb)
{
	if (plane_bomb)
	{
		if (plane_bomb->hitsGun())
		{
			return true;
		}
		SDL_Rect bombblack = plane_bomb->getBlack();
		SDL_FillRect(screen, &bombblack, SDL_MapRGB(screen->format, 0, 0, 0));
		plane_bomb->move();
		SDL_Rect bombtemp = plane_bomb->getDstRect();
		SDL_BlitSurface(plane_bomb->getSurface(), NULL, screen, &bombtemp);
	}
	return false;
}
