/*
Copyright 2006 Frank van der Loo

This file is part of Paratim.

Paratim is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

Paratim is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Paratim; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#include "plane.h"
#include "bomb.h"

// Creates a new plane
plane::plane(Direction d) : sprite(DATADIR, d == LEFT ? "/airplane2.bmp" : "/airplane.bmp")
{
 	if (d == LEFT)
	{
		dst.x = WIDTH;
	}
	else
	{
		dst.x = 0 - image->w;
	}
	dst.y = 5;
	dst.w = image->w;
	dst.h = image->h;
	black.w = image->w + 6;
	black.h = image->h + 6;
	black.x = dst.x - 3;
	black.y = dst.y - 3;
	points = 10;
	end = false;
	if (d == LEFT)
	{
		bombdrop_x = (rand()%250)+450;
	}
	else
	{
	 	bombdrop_x = (rand()%250)+50;
	}
	dir = d;
}

// Handles the events when a plane has been hit
void plane::hit(SDL_Surface *screen)
{
	end = true;
	SDL_Rect blacktmp = black;
	SDL_FillRect(screen, &blacktmp, SDL_MapRGB(screen->format, 0, 0, 0));
}

// Moves the plane a few pixels
void plane::move(SDL_Surface *screen)
{
 	SDL_Rect blacktemp = black;
	SDL_FillRect(screen, &blacktemp, SDL_MapRGB(screen->format, 0, 0, 0));
	SDL_Rect dsttemp = dst;
	SDL_BlitSurface(this->getSurface(), NULL, screen, &dsttemp);
	if (dir == LEFT)
	{
		if (dst.x < 0-image->w)
		{
			end = true;
			return;
		}
		dst.x-=3;
	}
	else
	{
		if (dst.x > WIDTH)
		{
		        end = true;
		        return;
		}
		dst.x+=3;
		
	}
	black.x = dst.x - 3;
}

// Lets the plane drop a bomb
bool plane::drop_bomb()
{
	if (dst.x <= bombdrop_x && dst.x > bombdrop_x-3)
		return true;
	return false;
}

// Moves the planes
void move_plane(SDL_Surface *screen, plane *airplane, bomb *plane_bomb)
{
	if (airplane)
	{
		if (!airplane->getEnd())
		{
			airplane->move(screen);
		}
		if (airplane->drop_bomb())
		{
			plane_bomb->init_bomb(airplane->getX(), airplane->getY());
		}
	}
}

// Return the number of planes that will be sent
int get_num_of_planes()
{
	int num_of_planes = /*rand()%*/5 + 1;
	#ifdef DEBUG
	  std::cout << "\nNum_of_planes: " << num_of_planes << std::endl;
	#endif
	return num_of_planes;
}

// Load the planes that will be used in their array
void set_planes(plane *planes[], int num_of_planes)
{
	for (int i=0;i<num_of_planes;i++)
	{
	 	if ((rand()%2 + 1) == 1)
		{
			std::cout << "left\n";
			planes[i] = new plane(LEFT);
		}
		else
		{
			std::cout << "right\n";
		 	planes[i] = new plane(RIGHT);
		}
	}	
}
